BOOST_PP_FOR_r_macros

This is a list, based on functionality, of the macros which have an alternate _r name, representing a reentry into the BOOST_PP_FOR looping construct:

repetition

- BOOST_PP_DEDUCE_R

list

- BOOST_PP_LIST_ENUM_R
- BOOST_PP_LIST_FOR_EACH_I_R
- BOOST_PP_LIST_FOR_EACH_PRODUCT_R
- BOOST_PP_LIST_FOR_EACH_R
- BOOST_PP_LIST_TO_SEQ_R
- BOOST_PP_LIST_TO_TUPLE_R

seq

- BOOST_PP_SEQ_FOR_EACH_PRODUCT_R
- BOOST_PP_SEQ_FOR_EACH_R

base

- BOOST_PP_FOR_R

© Copyright Edward Diener 2014

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)